summaryrefslogtreecommitdiff
path: root/lib/int.h
diff options
context:
space:
mode:
authorNikos Mavrogiannopoulos <nmav@gnutls.org>2012-10-06 14:29:37 +0200
committerNikos Mavrogiannopoulos <nmav@gnutls.org>2012-10-06 14:29:37 +0200
commit22dd88046a752020c9b7aec5710231da92cdbeb7 (patch)
tree64e9155520d48d3ca7df5668f3492bd2354da543 /lib/int.h
parent40e7731b1ff6b250744b76216945308dc7146213 (diff)
downloadlibtasn1-22dd88046a752020c9b7aec5710231da92cdbeb7.tar.gz
libtasn1-22dd88046a752020c9b7aec5710231da92cdbeb7.tar.bz2
libtasn1-22dd88046a752020c9b7aec5710231da92cdbeb7.zip
asn_ -> asn1_
Diffstat (limited to 'lib/int.h')
-rw-r--r--lib/int.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/lib/int.h b/lib/int.h
index 66d8a5c..696fb70 100644
--- a/lib/int.h
+++ b/lib/int.h
@@ -43,7 +43,7 @@
/* This structure is also in libtasn1.h, but then contains less
fields. You cannot make any modifications to these first fields
without breaking ABI. */
-struct asn_node_st
+struct asn1_node_st
{
/* public fields: */
char name[ASN1_MAX_NAME_SIZE+1]; /* Node name */
@@ -51,9 +51,9 @@ struct asn_node_st
unsigned int type; /* Node type */
unsigned char *value; /* Node value */
int value_len;
- asn_node_t down; /* Pointer to the son node */
- asn_node_t right; /* Pointer to the brother node */
- asn_node_t left; /* Pointer to the next list element */
+ asn1_node_t down; /* Pointer to the son node */
+ asn1_node_t right; /* Pointer to the brother node */
+ asn1_node_t left; /* Pointer to the next list element */
/* private fields: */
unsigned char small_value[ASN1_SMALL_VALUE_SIZE]; /* For small values */
};
@@ -74,11 +74,11 @@ struct asn_node_st
/****************************************/
/* Returns the first 8 bits. */
/* Used with the field type of asn_node_st */
/****************************************/
#define type_field(x) (x&0xFF)
/* List of constants for field type of typedef asn_node_st */
#define TYPE_CONSTANT ASN1_ETYPE_CONSTANT
#define TYPE_IDENTIFIER ASN1_ETYPE_IDENTIFIER
#define TYPE_INTEGER ASN1_ETYPE_INTEGER
@@ -104,7 +104,7 @@ struct asn_node_st
/***********************************************************************/
/* List of constants to better specify the type of typedef asn_node_st. */
/***********************************************************************/
/* Used with TYPE_TAG */
#define CONST_UNIVERSAL (1<<8)
@@ -74,11 +74,11 @@ struct asn_node_st
/****************************************/
/* Returns the first 8 bits. */
-/* Used with the field type of asn_node_st */
+/* Used with the field type of asn1_node_st */
/****************************************/
#define type_field(x) (x&0xFF)
@@ -74,11 +74,11 @@ struct asn_node_st
/****************************************/
#define type_field(x) (x&0xFF)
-/* List of constants for field type of typedef asn_node_st */
+/* List of constants for field type of typedef asn1_node_st */
#define TYPE_CONSTANT ASN1_ETYPE_CONSTANT
#define TYPE_IDENTIFIER ASN1_ETYPE_IDENTIFIER
@@ -104,7 +104,7 @@ struct asn_node_st
/***********************************************************************/
-/* List of constants to better specify the type of typedef asn_node_st. */
+/* List of constants to better specify the type of typedef asn1_node_st. */
/***********************************************************************/
/* Used with TYPE_TAG */